@@ -1,7 +1,8 @@
+import numpy as np
 import pytest
 from sklearn.model_selection import KFold
 
-from vivid.utils import get_train_valid_set
+from vivid.utils import get_train_valid_set, sigmoid
 
 
 def test_get_train_test_set():
@@ -15,3 +16,9 @@ def test_get_train_test_set():
     y2 = []
     with pytest.raises(ValueError):
         get_train_valid_set(fold1, x, y2)
+
+
+def test_sigmoid():
+    x = 10000  # too large value
+    y = sigmoid(-x)
+    np.log(y)  # not set threshold, overflow in the log operation
